/*
 * Copyright 2007 The authors
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.struts2.dom.struts.action;

import com.intellij.util.xml.ConvertContext;
import com.intellij.util.xml.ResolvingConverter;
import org.jetbrains.annotations.NotNull;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

/**
 * Provide defaults for <code>result</code> "name"-attribute.
 *
 * @author Yann Cbron
 * @see com.intellij.struts2.dom.struts.action.Result#getName() 
 */
public class ResultNameConverter extends ResolvingConverter.StringConverter {

  private static final Set<String> defaultNames = new HashSet<String>(4);

  static {
    defaultNames.add("error");
    defaultNames.add("input");
    defaultNames.add("login");
    defaultNames.add("success");
  }

  @NotNull
  public Collection<? extends String> getVariants(final ConvertContext context) {
    return defaultNames;
  }

}