/*
 * Copyright 2007 The authors
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.struts2;

import com.intellij.openapi.fileTypes.StdFileTypes;
import com.intellij.openapi.util.IconLoader;
import com.intellij.ui.LayeredIcon;
import org.jetbrains.annotations.NonNls;

import javax.swing.*;

/**
 * All icons.
 *
 * @author Yann Cbron
 */
public final class StrutsIcons {

  /**
   * Icon for struts.xml files in tree/structure view.
   */
  public static final LayeredIcon STRUTS_CONFIG_FILE_ICON = new LayeredIcon(2);

  /**
   * Icon for validation.xml files in tree/structure view.
   */
  public static final LayeredIcon VALIDATION_CONFIG_FILE_ICON = new LayeredIcon(2);

  private StrutsIcons() {
  }

  @NonNls
  private static final String ICON_BASE_PATH = "/resources/icons/";

  /**
   * Loads the icon with the given name from the default icon base path.
   *
   * @param iconName Relative file name of the icon to load.
   *
   * @return Icon.
   */
  public static Icon getIcon(@NonNls final String iconName) {
    return IconLoader.getIcon(ICON_BASE_PATH + iconName);
  }

  /**
   * Vertical offset for small overlay icons.
   */
  public static final int SMALL_ICON_Y_OFFSET = 6;

  // DOM ------------------------------------------------

  public static final Icon ACTION = getIcon("action.png");
  public static final Icon ACTION_SMALL = getIcon("action_small.png");
  public static final Icon BEAN = getIcon("coffeebean.png");
  public static final Icon INCLUDE = getIcon("import1.png");
  public static final Icon INTERCEPTOR = getIcon("funnel.png");
  public static final Icon INTERCEPTOR_STACK = getIcon("funnel_up.png");
  public static final Icon DEFAULT_INTERCEPTOR = getIcon("funnel_preferences.png");
  public static final Icon PACKAGE = getIcon("folder_gear.png");
  public static final Icon PARAM = getIcon("preferences.png");
  public static final Icon RESULT = getIcon("arrow_right_blue.png");
  public static final Icon RESULT_TYPE = getIcon("presentation.png");

  public static final Icon VALIDATOR = getIcon("validation.png");
  public static final Icon VALIDATOR_SMALL = getIcon("validation_small.png");
  public static final Icon MESSAGE = getIcon("message.png");


  // generic reference providers
  public static final Icon THEME = getIcon("transform.png");

  static {
    STRUTS_CONFIG_FILE_ICON.setIcon(StdFileTypes.XML.getIcon(), 0);
    STRUTS_CONFIG_FILE_ICON.setIcon(ACTION_SMALL, 1, 0, SMALL_ICON_Y_OFFSET);

    VALIDATION_CONFIG_FILE_ICON.setIcon(StdFileTypes.XML.getIcon(), 0);
    VALIDATION_CONFIG_FILE_ICON.setIcon(VALIDATOR_SMALL, 1, 0, SMALL_ICON_Y_OFFSET);
  }

}