/*
 * Copyright 2007 The authors
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.struts2.dom.inspection;

import com.intellij.openapi.compiler.CompileContext;
import com.intellij.openapi.compiler.CompileScope;
import com.intellij.openapi.module.Module;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vfs.VirtualFile;
import com.intellij.openapi.vfs.pointers.VirtualFilePointer;
import com.intellij.struts2.dom.struts.model.StrutsManager;
import com.intellij.struts2.facet.StrutsFacet;
import com.intellij.struts2.facet.configuration.StrutsFileSet;
import com.intellij.struts2.facet.configuration.StrutsValidationConfiguration;
import com.intellij.util.containers.ContainerUtil;

import java.util.Collection;
import java.util.HashSet;
import java.util.Set;

/**
 * Validator for struts.xml files when running "Make Project".
 *
 * @author Yann Cebron
 */
public class Struts2ModelValidator extends ValidatorBase {

  public Struts2ModelValidator() {
    super("Struts 2 Model Validator", "Validating Struts 2 model...", Struts2ModelInspection.class);
  }

  protected boolean isValidationEnabledForModel(final StrutsValidationConfiguration validationConfiguration) {
    return validationConfiguration.isValidateStruts();
  }

  public Collection<VirtualFile> getFilesToProcess(final Project project, final CompileContext context) {
    final StrutsManager strutsManager = StrutsManager.getInstance(project);

    final Set<VirtualFile> files = new HashSet<VirtualFile>();
    final CompileScope scope = context.getCompileScope();
    for (final Module module : scope.getAffectedModules()) {
      final StrutsFacet strutsFacet = StrutsFacet.getInstance(module);
      if (strutsFacet != null) {
        for (final StrutsFileSet fileSet : strutsManager.getAllConfigFileSets(module)) {
          for (final VirtualFilePointer pointer : fileSet.getFiles()) {
            final VirtualFile file = pointer.getFile();
            ContainerUtil.addIfNotNull(file, files);
          }
        }
      }
    }

    // TODO do not check struts.xml files which are not configured in filesets ?!
//    final PsiManager psiManager = PsiManager.getInstance(project);
//    final DomManager domManager = DomManager.getDomManager(project);
//    for (final VirtualFile file : scope.getFiles(StdFileTypes.XML, false)) {
//      final Module module = context.getModuleByFile(file);
//      if (module != null) {
//        addStrutsConfigFile(files, file, psiManager, domManager);
//      }
//    }

    return files;
  }

}