/*
 * Copyright 2007 The authors
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.intellij.struts2.dom.struts.impl;

import com.intellij.struts2.dom.ConverterUtil;
import com.intellij.struts2.dom.struts.model.StrutsModel;
import com.intellij.struts2.dom.struts.strutspackage.StrutsPackage;
import com.intellij.struts2.dom.struts.strutspackage.StrutsPackageExtendsResolveConverter;
import com.intellij.util.xml.ConvertContext;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;
import java.util.Collections;

/**
 * @author Yann Cbron
 */
public class StrutsPackageExtendsResolveConverterImpl extends StrutsPackageExtendsResolveConverter {

  @NotNull
  public Collection<? extends StrutsPackage> getVariants(final ConvertContext context) {

    // current struts.xml not in DOMModel
    final StrutsModel strutsModel = ConverterUtil.getStrutsModel(context);
    if (strutsModel == null) {
      return Collections.emptySet();
    }

    return filterVariants(context, strutsModel.getStrutsPackages());
  }

  @Nullable
  public StrutsPackage fromString(@Nullable @NonNls final String name, final ConvertContext context) {
    if (name == null) {
      return null;
    }

    final StrutsModel strutsModel = ConverterUtil.getStrutsModel(context);

    // current struts.xml not in DOM-Model
    if (strutsModel == null) {
      return null;
    }

    final Collection<? extends StrutsPackage> packages = getVariants(context);
    for (final StrutsPackage strutsPackage : packages) {
      if (name.equals(strutsPackage.getName().getStringValue())) {
        return strutsPackage;
      }
    }

    return null;
  }

}